pitchtools.IntervalClassObjectSet
=================================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet

.. autoclass:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.intersection
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.isdisjoint
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.issubset
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.issuperset
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.union
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__cmp__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__rand__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__ror__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__rsub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__rxor__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__sub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalClassObjectSet.IntervalClassObjectSet.IntervalClassObjectSet.__xor__
   :noindex:
